##  Results
After your provisioning request is completed, SAP will send you an email that contains the workspace URL. For your provided workspace, you can access the URL anytime from SAP for Me. To find it, follow the link in the Provisioned System table. The data center that hosts your platform will be assigned according to the region stated in your contract or a data center in the next available region.
Your workspace name, URL, and tenant ID is automatically determined based your data in the SAP CRM system. If you require a different workspace name, reach out to the support team.
If you encounter any issues during provisioning, contact support. Learn how in [Contact Support](https://help.sap.com/docs/leanix/ea/contact-support?locale=en-US&state=PRODUCTION&version=CLOUD "If you encounter issues, have questions, or need assistance with SAP LeanIX, our support team is here to help. You can contact support directly within SAP LeanIX or submit a request in the SAP for Me portal.").
